@@ -19,62 +19,6 @@ class LedBrightness(enum.Enum):
     Off = 2
 
 
-class AirHumidifier(Device):
-    """Main class representing the air humidifier."""
-
-    def status(self):
-        """Retrieve properties."""
-
-        properties = ['power', 'mode', 'temp_dec', 'humidity', 'buzzer',
-                      'led_b', ]
-
-        values = self.send(
-            "get_prop",
-            properties
-        )
-
-        properties_count = len(properties)
-        values_count = len(values)
-        if properties_count != values_count:
-            _LOGGER.debug(
-                "Count (%s) of requested properties does not match the "
-                "count (%s) of received values.",
-                properties_count, values_count)
-
-        return AirHumidifierStatus(
-            defaultdict(lambda: None, zip(properties, values)))
-
-    def on(self):
-        """Power on."""
-        return self.send("set_power", ["on"])
-
-    def off(self):
-        """Power off."""
-        return self.send("set_power", ["off"])
-
-    def set_mode(self, mode: OperationMode):
-        """Set mode."""
-        return self.send("set_mode", [mode.value])
-
-    def set_led_brightness(self, brightness: LedBrightness):
-        """Set led brightness."""
-        return self.send("set_led_b", [brightness.value])
-
-    def set_led(self, led: bool):
-        """Turn led on/off."""
-        if led:
-            return self.send("set_led", ['on'])
-        else:
-            return self.send("set_led", ['off'])
-
-    def set_buzzer(self, buzzer: bool):
-        """Set buzzer on/off."""
-        if buzzer:
-            return self.send("set_buzzer", ["on"])
-        else:
-            return self.send("set_buzzer", ["off"])
-
-
 class AirHumidifierStatus:
     """Container for status reports from the air humidifier."""
 
@@ -123,3 +67,59 @@ class AirHumidifierStatus:
             (self.power, self.mode, self.temperature,
              self.humidity, self.led, self.led_brightness, self.buzzer)
         return s
+
+
+class AirHumidifier(Device):
+    """Main class representing the air humidifier."""
+
+    def status(self) -> AirHumidifierStatus:
+        """Retrieve properties."""
+
+        properties = ['power', 'mode', 'temp_dec', 'humidity', 'buzzer',
+                      'led_b', ]
+
+        values = self.send(
+            "get_prop",
+            properties
+        )
+
+        properties_count = len(properties)
+        values_count = len(values)
+        if properties_count != values_count:
+            _LOGGER.debug(
+                "Count (%s) of requested properties does not match the "
+                "count (%s) of received values.",
+                properties_count, values_count)
+
+        return AirHumidifierStatus(
+            defaultdict(lambda: None, zip(properties, values)))
+
+    def on(self):
+        """Power on."""
+        return self.send("set_power", ["on"])
+
+    def off(self):
+        """Power off."""
+        return self.send("set_power", ["off"])
+
+    def set_mode(self, mode: OperationMode):
+        """Set mode."""
+        return self.send("set_mode", [mode.value])
+
+    def set_led_brightness(self, brightness: LedBrightness):
+        """Set led brightness."""
+        return self.send("set_led_b", [brightness.value])
+
+    def set_led(self, led: bool):
+        """Turn led on/off."""
+        if led:
+            return self.send("set_led", ['on'])
+        else:
+            return self.send("set_led", ['off'])
+
+    def set_buzzer(self, buzzer: bool):
+        """Set buzzer on/off."""
+        if buzzer:
+            return self.send("set_buzzer", ["on"])
+        else:
+            return self.send("set_buzzer", ["off"])
