@@ -3,9 +3,9 @@ import zeroconf
 import ipaddress
 import inspect
 import codecs
-from . import (Device, Vacuum, Plug, PlugV1, Strip, AirPurifier, Ceil,
-               PhilipsEyecare, ChuangmiIr, AirHumidifier, WaterPurifier,
-               WifiSpeaker, Yeelight)
+from . import (Device, Vacuum, Plug, PlugV1, PowerStrip, AirPurifier, Ceil,
+               PhilipsBulb, PhilipsEyecare, ChuangmiIr, AirHumidifier,
+               WaterPurifier, WifiSpeaker, Yeelight)
 from typing import Union, Callable, Dict, Optional  # noqa: F401
 
 
@@ -17,8 +17,9 @@ DEVICE_MAP = {
     "chuangmi-plug-m1": Plug,
     "chuangmi-plug-v2": Plug,
     "chuangmi-plug-v1": PlugV1,
-    "qmi-powerstrip-v1": Strip,
-    "zimi-powerstrip-v2": Strip,
+    "chuangmi-plug_": PlugV1,
+    "qmi-powerstrip-v1": PowerStrip,
+    "zimi-powerstrip-v2": PowerStrip,
     "zhimi-airpurifier-m1": AirPurifier,
     "zhimi-airpurifier-m2": AirPurifier,
     "zhimi-airpurifier-v1": AirPurifier,
@@ -29,7 +30,7 @@ DEVICE_MAP = {
     "zhimi-humidifier-v1": AirHumidifier,
     "yunmi-waterpuri-v2": WaterPurifier,
     # It looks like philips devices cannot be discovered via mdns
-    "philips-light-bulb": Ceil,
+    "philips-light-bulb": PhilipsBulb,
     "philips-light-ceil": Ceil,
     "philips-light-sread1": PhilipsEyecare,
     "xiaomi-wifispeaker-v1": WifiSpeaker,  # name needs to be checked
